"""
// © University of Southampton IT Innovation Centre, 2018
//
// Copyright in this software belongs to University of Southampton
// IT Innovation Centre of Gamma House, Enterprise Road,
// Chilworth Science Park, Southampton, SO16 7NS, UK.
//
// This software may not be used, sold, licensed, transferred, copied
// or reproduced in whole or in part in any manner or form or in or
// on any media by any person other than in accordance with the terms
// of the Licence Agreement supplied with the software, or otherwise
// without the prior written consent of the copyright owners.
//
// This software is distributed WITHOUT ANY WARRANTY, without even the
// implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
// PURPOSE, except where stated in the Licence Agreement supplied with
// the software.
//
//      Created By :            Nikolay Stanchev
//      Created Date :          15-05-2018
//      Created for Project :   FLAME
"""

from pyramid.view import view_defaults
from pyramid.httpexceptions import HTTPBadRequest
from clmcservice.utilities import validate_content, CONFIG_ATTRIBUTES


@view_defaults(route_name='aggregator', renderer='json')
class AggregatorConfig(object):
    """
    A class-based view for accessing and mutating the status of the aggregator.
    """

    def __init__(self, request):
        """
        Initialises the instance of the view with the request argument.
        :param request: client's call request
        """

        self.request = request

    def get(self):
        """
        A GET API call for the status of the aggregator.
        :return: A JSON response with the status of the aggregator.
        """

        aggregator_data = self.request.registry.settings
        return {key: aggregator_data.get(key) for key in CONFIG_ATTRIBUTES}

    def post(self):
        """
        A POST API call for the status of the aggregator.
        :return: A JSON response to the POST call (success or fail).
        :raises HTTPBadRequest: if form argument cannot be converted to boolean
        """

        new_config = self.request.body.decode(self.request.charset)

        try:
            new_config = validate_content(new_config)

            for attribute in CONFIG_ATTRIBUTES:
                self.request.registry.settings[attribute] = new_config.get(attribute)

            # TODO start/stop aggregator based on value of new status
            return new_config

        except AssertionError:
            raise HTTPBadRequest("Bad request content - configuration format is incorrect.")
